betty.wikipedia.copyright_notice module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.wikipedia.copyright_notice module

Wikipedia copyright notices.

class betty.wikipedia.copyright_notice.WikipediaContributors

  Bases: `ShorthandPluginBase`, `AppDependentFactory`, `CopyrightNotice`

  The copyright for resources on Wikipedia.

  __init__(urls: Mapping[str, str])
  async classmethod new(fetcher: Fetcher) → Self

    Create a new instance.

  async classmethod new_for_app(app: App) → Self

    Create a new instance using the given app.

  property summary: Localizable

    The copyright summary.

  property text: Localizable

    The full copyright text.

  property url: Localizable

    The URL to an external human-readable resource with more information about this copyright.